@@ -13,7 +13,7 @@
 #include "RrdaDecoder.h"
 
 
-bool releaseDataFile(ArchiveConfig& archive_config) {
+bool releaseDataFile(const ArchiveConfig& archive_config) {
 
   RrdaDecoder decoder(archive_config.getReleaseName(),
                       archive_config.getRrdaKey());
