@@ -13,6 +13,9 @@
 #include "ui_ReleaseDialogForm.h"
 
 
+/*!
+  \brief リリースダイアログ管理クラス
+*/
 class ReleaseDialog : public QDialog, private Ui::ReleaseDialog {
   Q_OBJECT;
 
@@ -26,7 +29,13 @@ private slots:
   void acceptedHandler(void);
 
 public:
-  ReleaseDialog(QDialog* parent = 0);
+
+  /*!
+    \brief コンストラクタ
+
+    \param parent [i] 親ウィジット
+  */
+  explicit ReleaseDialog(QDialog* parent = 0);
   ~ReleaseDialog(void);
 
 
