@@ -18,6 +18,9 @@
 #include "SettingConfig.h"
 #include "ReleaseDialog.h"
 #include "ReleaseDataFile.h"
+#include "ToSjisString.h"
+
+using namespace qrk;
 
 
 namespace {
@@ -795,6 +798,9 @@ void ThemeConfigWindow::openFile(void) {
                                  tr("archive list (*.txt)"));
 
   if (! fileName.isEmpty()) {
+    // 日本語のパスを含む場合への対処
+    fileName = toSjisString(fileName);
+
     pimpl->loadArchiveFile(this, fileName.toStdString().c_str());
     pimpl->setSaveEnabled(this, false);
   }
@@ -827,6 +833,9 @@ void ThemeConfigWindow::saveFileAs(void) {
                                  tr("archive list (*.txt)"));
 
   if (! fileName.isEmpty()) {
+    // 日本語のパスを含む場合への対処
+    fileName = toSjisString(fileName);
+
     pimpl->save(this, fileName.toStdString().c_str());
   }
 }
@@ -993,6 +1002,9 @@ void ThemeConfigWindow::updateHandlelr(void) {
                                  tr("parts file (*.png)"));
 
   if (! fileName.isEmpty()) {
+    // 日本語のパスを含む場合への対処
+    fileName = toSjisString(fileName);
+
     pimpl->updateItemName(fileName.toStdString().c_str());
   }
 }
