@@ -53,6 +53,12 @@ private slots:
   void releaseHandler(const QString& file, const QString& key);
 
 public:
+
+  /*!
+    \brief コンストラクタ
+
+    \param config_file [i] テーマ設定ファイル
+  */
   explicit ThemeConfigWindow(const QString& config_file = "");
   ~ThemeConfigWindow(void);
 };
